@@ -88,12 +88,12 @@ extern "C" {
     typedef struct st_sdbi_fields {
         int num_fields;
         char **name;            /* DBMS field names */
-        Sint *type;             /* DBMS internal types */
-        Sint *length;           /* DBMS lengths in bytes */
-        Sint *precision;        /* DBMS num of digits for numeric types */
-        Sint *scale;            /* DBMS num of decimals for numeric types */
-        Sint *nullOk;           /* DBMS indicator for DBMS'  NULL type */
-        Sint *isVarLength;      /* DBMS variable-length char type */
+        int *type;             /* DBMS internal types */
+        int *length;           /* DBMS lengths in bytes */
+        int *precision;        /* DBMS num of digits for numeric types */
+        int *scale;            /* DBMS num of decimals for numeric types */
+        int *nullOk;           /* DBMS indicator for DBMS'  NULL type */
+        int *isVarLength;      /* DBMS variable-length char type */
         Stype *Sclass;          /* R/S class (type) -- may be overriden */
         /* TODO: Need a table of fun pointers to converters */
     } RS_DBI_fields;
@@ -111,14 +111,14 @@ extern "C" {
     typedef struct st_sdbi_resultset {
         void *drvResultSet;     /* the actual (driver's) cursor/result set */
         void *drvData;          /* a pointer to driver-specific data */
-        Sint managerId;         /* the 3 *Id's are used for   */
-        Sint connectionId;      /* validating stuff coming from S */
-        Sint resultSetId;
-        Sint isSelect;          /* boolean for testing SELECTs */
+        int managerId;         /* the 3 *Id's are used for   */
+        int connectionId;      /* validating stuff coming from S */
+        int resultSetId;
+        int isSelect;          /* boolean for testing SELECTs */
         char *statement;        /* SQL statement */
-        Sint rowsAffected;      /* used by non-SELECT statements */
-        Sint rowCount;          /* rows fetched so far (SELECT-types) */
-        Sint completed;         /* have we fetched all rows? */
+        int rowsAffected;      /* used by non-SELECT statements */
+        int rowCount;          /* rows fetched so far (SELECT-types) */
+        int completed;         /* have we fetched all rows? */
         RS_DBI_fields *fields;
     } RS_DBI_resultSet;
 
@@ -134,12 +134,12 @@ extern "C" {
         void *drvConnection;    /* pointer to the actual DBMS connection struct */
         void *drvData;          /* to be used at will by individual drivers */
         RS_DBI_resultSet **resultSets;  /* vector to result set ptrs  */
-        Sint *resultSetIds;
-        Sint length;            /* max num of concurrent resultSets */
-        Sint num_res;           /* num of open resultSets */
-        Sint counter;           /* total number of queries */
-        Sint managerId;
-        Sint connectionId;
+        int *resultSetIds;
+        int length;            /* max num of concurrent resultSets */
+        int num_res;           /* num of open resultSets */
+        int counter;           /* total number of queries */
+        int managerId;
+        int connectionId;
         RS_DBI_exception *exception;
     } RS_DBI_connection;
 
@@ -148,12 +148,12 @@ extern "C" {
         char *drvName;          /* what driver are we implementing? */
         void *drvData;          /* to be used by the drv implementation */
         RS_DBI_connection **connections;        /* list of dbConnections */
-        Sint *connectionIds;    /* array of connectionIds */
-        Sint length;            /* max num of concurrent connections */
-        Sint num_con;           /* num of opened connections */
-        Sint counter;           /* num of connections handled so far */
-        Sint fetch_default_rec; /* default num of records per fetch */
-        Sint managerId;         /* typically, process id */
+        int *connectionIds;    /* array of connectionIds */
+        int length;            /* max num of concurrent connections */
+        int num_con;           /* num of opened connections */
+        int counter;           /* num of connections handled so far */
+        int fetch_default_rec; /* default num of records per fetch */
+        int managerId;         /* typically, process id */
         RS_DBI_exception *exception;
     } RS_DBI_manager;
 
@@ -164,24 +164,24 @@ extern "C" {
      * return handles.  All DBI functions (free/get/etc) use the handle
      * to work with the various dbObjects.
      */
-    Mgr_Handle *RS_DBI_allocManager(const char *drvName, Sint max_con, Sint fetch_default_rec, Sint force_realloc);
+    Mgr_Handle *RS_DBI_allocManager(const char *drvName, int max_con, int fetch_default_rec, int force_realloc);
     void RS_DBI_freeManager(Mgr_Handle * mgrHandle);
     RS_DBI_manager *RS_DBI_getManager(Db_Handle * handle);
-    Mgr_Handle *RS_DBI_asMgrHandle(Sint pid);
+    Mgr_Handle *RS_DBI_asMgrHandle(int pid);
     s_object *RS_DBI_managerInfo(Mgr_Handle * mgrHandle);
 
     /* dbConnection */
-    Con_Handle *RS_DBI_allocConnection(Mgr_Handle * mgrHandle, Sint max_res);
+    Con_Handle *RS_DBI_allocConnection(Mgr_Handle * mgrHandle, int max_res);
     void RS_DBI_freeConnection(Con_Handle * conHandle);
     RS_DBI_connection *RS_DBI_getConnection(Db_Handle * handle);
-    Con_Handle *RS_DBI_asConHandle(Sint mgrId, Sint conId);
+    Con_Handle *RS_DBI_asConHandle(int mgrId, int conId);
     s_object *RS_DBI_connectionInfo(Con_Handle * con_Handle);
 
     /* dbResultSet */
     Res_Handle *RS_DBI_allocResultSet(Con_Handle * conHandle);
     void RS_DBI_freeResultSet(Res_Handle * rsHandle);
     RS_DBI_resultSet *RS_DBI_getResultSet(Res_Handle * rsHandle);
-    Res_Handle *RS_DBI_asResHandle(Sint pid, Sint conId, Sint resId);
+    Res_Handle *RS_DBI_asResHandle(int pid, int conId, int resId);
     s_object *RS_DBI_resultSetInfo(Res_Handle * rsHandle);
 
     /* utility funs */
@@ -197,10 +197,10 @@ extern "C" {
      * connection object;  of course, this is transparent to the various
      * drivers -- they should deal with handles exclusively.
      */
-    Sint RS_DBI_newEntry(Sint * table, Sint length);
-    Sint RS_DBI_lookup(Sint * table, Sint length, Sint obj_id);
-    Sint RS_DBI_listEntries(Sint * table, Sint length, Sint * entries);
-    void RS_DBI_freeEntry(Sint * table, Sint indx);
+    int RS_DBI_newEntry(int * table, int length);
+    int RS_DBI_lookup(int * table, int length, int obj_id);
+    int RS_DBI_listEntries(int * table, int length, int * entries);
+    void RS_DBI_freeEntry(int * table, int indx);
 
     /* description of the fields in a result set */
     RS_DBI_fields *RS_DBI_allocFields(int num_fields);
@@ -211,7 +211,7 @@ extern "C" {
      * RS_DBI_fields).  This should be some kind of R/S "relation"
      * table, not a dataframe nor a list.
      */
-    void RS_DBI_allocOutput(s_object * output, RS_DBI_fields * flds, Sint num_rec, Sint expand);
+    void RS_DBI_allocOutput(s_object * output, RS_DBI_fields * flds, int num_rec, int expand);
     void RS_DBI_makeDataFrame(s_object * data);
 
     /* TODO: We need to elevate RS_DBI_errorMessage to either
@@ -230,15 +230,15 @@ extern "C" {
      */
     struct data_types {
         char *typeName;
-        Sint typeId;
+        int typeId;
     };
 
     /* return the primitive type name for a primitive type id */
-    const char *RS_DBI_getTypeName(Sint typeCode, const struct data_types table[]);
+    const char *RS_DBI_getTypeName(int typeCode, const struct data_types table[]);
     /* same, but callable from S/R and vectorized */
     s_object *RS_DBI_SclassNames(s_object * types);
 
-    s_object *RS_DBI_createNamedList(char **names, Stype * types, Sint * lengths, Sint n);
+    s_object *RS_DBI_createNamedList(char **names, Stype * types, int * lengths, int n);
     s_object *RS_DBI_copyFields(RS_DBI_fields * flds);
 
     void RS_na_set(void *ptr, Stype type);
